﻿Imports System.Data.SqlClient
Imports ThinkGeo.MapSuite.Layers
Imports ThinkGeo.MapSuite.Styles
Imports ThinkGeo.MapSuite.Drawing
Imports ThinkGeo.MapSuite.WinForms
Imports ThinkGeo.MapSuite.Shapes

Public Class Form1
  Private moStandsLayer As ShapeFileFeatureLayer
  Private moGeoTiffLayer As GeoTiffRasterLayer
  Private sTiffPath As String = "..\..\Data\LowerForty.Tif"
  Private sStandsPath As String = "..\..\Data\Stands.shp"
  Private Sub Form1_Load(sender As Object, e As EventArgs) Handles Me.Load
    Dim oLayerOverlay As New LayerOverlay
    Dim oProj4 As New UnmanagedProj4Projection

    ZoomLevelHelper.InitZoomLevels()
    ZoomLevelHelper.LoadScaleComboZoomLevels(cboScale)
    'ZoomLevelHelper.ApplyCustomZoomLevels(WinformsMap1)

    moGeoTiffLayer = New GeoTiffRasterLayer(sTiffPath)
    oProj4.InternalProjectionParametersString = Proj4Projection.GetEsriParametersString(26916)
    oProj4.ExternalProjectionParametersString = Proj4Projection.GetEsriParametersString(102003)
    moGeoTiffLayer.ImageSource.Projection = oProj4

    oLayerOverlay.Layers.Add(moGeoTiffLayer)

    moStandsLayer = New ShapeFileFeatureLayer(sStandsPath)
    moStandsLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColors.Transparent, GeoColors.Red, 2)
    moStandsLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20
    oLayerOverlay.Layers.Add(moStandsLayer)


    moStandsLayer.Open()
    Dim oFeature As Feature = moStandsLayer.QueryTools.GetFeaturesByColumnValue("StandKey", "40700355", ReturningColumnsType.AllColumns)(0)

    Dim oMapExtent As RectangleShape = oFeature.GetBoundingBox

    With WinformsMap1.ExtentOverlay
      .MouseWheelMode = MapMouseWheelMode.Zooming
      .ZoomPercentage = 10
    End With

    WinformsMap1.MinimumScale = 1
    WinformsMap1.Overlays.Add(oLayerOverlay)
    WinformsMap1.MapUnit = ThinkGeo.MapSuite.GeographyUnit.Meter
    WinformsMap1.ZoomLevelSnapping = ZoomLevelSnappingMode.SnapUp
    ZoomLevelHelper.ApplyCustomZoomLevels(WinformsMap1.ZoomLevelSet)

    WinformsMap1.CurrentExtent = oMapExtent
    WinformsMap1.Refresh()
  End Sub

  Private Sub WinformsMap1_CurrentScaleChanged(sender As Object, e As CurrentScaleChangedWinformsMapEventArgs) Handles WinformsMap1.CurrentScaleChanged
    Dim oMap As WinformsMap = TryCast(sender, WinformsMap)
    If oMap Is Nothing Then
      Return
    End If

    With oMap
      txtScale.Text = "Scale: " & String.Format("{0:#,###.00} ft / in", .CurrentScale / 12)

      '***** Set the scale combo box to its correct value
      Dim oComboBoxTool As ComboBox = cboScale
      ZoomLevelHelper.SetListByValueMember(cboScale, CInt(.CurrentScale))
    End With

  End Sub

  Private Sub cboScale_SelectionChangeCommitted(sender As Object, e As EventArgs) Handles cboScale.SelectionChangeCommitted
    WinformsMap1.CurrentScale = cboScale.SelectedValue
    WinformsMap1.Refresh()
  End Sub
End Class
